@@ -28,44 +28,41 @@ __arch=$(dpkg --print-architecture)
 __jvm_default="/usr/lib/jvm/default-java"
 
 # Oracle runtimes
-__jvm_oracle7="/usr/lib/jvm/java-7-oracle /usr/lib/jvm/jdk-7-oracle-* /usr/lib/jvm/jre-7-oracle-*"
 __jvm_oracle8="/usr/lib/jvm/java-8-oracle /usr/lib/jvm/jdk-8-oracle-* /usr/lib/jvm/jre-8-oracle-*"
-__jvm_oracle9="/usr/lib/jvm/java-9-oracle /usr/lib/jvm/jdk-9-oracle-* /usr/lib/jvm/jre-9-oracle-*"
-__jvm_oracle10="/usr/lib/jvm/java-10-oracle /usr/lib/jvm/jdk-10-oracle-* /usr/lib/jvm/jre-10-oracle-*"
 __jvm_oracle11="/usr/lib/jvm/java-11-oracle /usr/lib/jvm/jdk-11-oracle-* /usr/lib/jvm/jre-11-oracle-*"
 __jvm_oracle17="/usr/lib/jvm/java-17-oracle /usr/lib/jvm/jdk-17-oracle-* /usr/lib/jvm/jre-17-oracle-*"
-__jvm_oracle18="/usr/lib/jvm/java-18-oracle /usr/lib/jvm/jdk-18-oracle-* /usr/lib/jvm/jre-18-oracle-*"
-__jvm_oracle19="/usr/lib/jvm/java-19-oracle /usr/lib/jvm/jdk-19-oracle-* /usr/lib/jvm/jre-19-oracle-*"
-__jvm_oracle20="/usr/lib/jvm/java-20-oracle /usr/lib/jvm/jdk-20-oracle-* /usr/lib/jvm/jre-20-oracle-*"
+__jvm_oracle21="/usr/lib/jvm/java-21-oracle /usr/lib/jvm/jdk-21-oracle-* /usr/lib/jvm/jre-21-oracle-*"
+__jvm_oracle22="/usr/lib/jvm/java-22-oracle /usr/lib/jvm/jdk-22-oracle-* /usr/lib/jvm/jre-22-oracle-*"
+__jvm_oracle23="/usr/lib/jvm/java-23-oracle /usr/lib/jvm/jdk-23-oracle-* /usr/lib/jvm/jre-23-oracle-*"
+__jvm_oracle24="/usr/lib/jvm/java-24-oracle /usr/lib/jvm/jdk-24-oracle-* /usr/lib/jvm/jre-24-oracle-*"
+__jvm_oracle25="/usr/lib/jvm/java-25-oracle /usr/lib/jvm/jdk-25-oracle-* /usr/lib/jvm/jre-25-oracle-*"
 
 # Now, free runtimes:
-__jvm_openjdk6="/usr/lib/jvm/java-6-openjdk-$__arch /usr/lib/jvm/java-6-openjdk"
-__jvm_openjdk7="/usr/lib/jvm/java-7-openjdk-$__arch /usr/lib/jvm/java-7-openjdk"
 __jvm_openjdk8="/usr/lib/jvm/java-8-openjdk-$__arch /usr/lib/jvm/java-8-openjdk"
-__jvm_openjdk9="/usr/lib/jvm/java-9-openjdk-$__arch /usr/lib/jvm/java-9-openjdk"
-__jvm_openjdk10="/usr/lib/jvm/java-10-openjdk-$__arch /usr/lib/jvm/java-10-openjdk"
 __jvm_openjdk11="/usr/lib/jvm/java-11-openjdk-$__arch /usr/lib/jvm/java-11-openjdk"
 __jvm_openjdk17="/usr/lib/jvm/java-17-openjdk-$__arch /usr/lib/jvm/java-17-openjdk"
-__jvm_openjdk18="/usr/lib/jvm/java-18-openjdk-$__arch /usr/lib/jvm/java-18-openjdk"
-__jvm_openjdk19="/usr/lib/jvm/java-19-openjdk-$__arch /usr/lib/jvm/java-19-openjdk"
-__jvm_openjdk20="/usr/lib/jvm/java-20-openjdk-$__arch /usr/lib/jvm/java-20-openjdk"
+__jvm_openjdk21="/usr/lib/jvm/java-21-openjdk-$__arch /usr/lib/jvm/java-21-openjdk"
+__jvm_openjdk22="/usr/lib/jvm/java-22-openjdk-$__arch /usr/lib/jvm/java-22-openjdk"
+__jvm_openjdk23="/usr/lib/jvm/java-23-openjdk-$__arch /usr/lib/jvm/java-23-openjdk"
+__jvm_openjdk24="/usr/lib/jvm/java-24-openjdk-$__arch /usr/lib/jvm/java-24-openjdk"
+__jvm_openjdk25="/usr/lib/jvm/java-25-openjdk-$__arch /usr/lib/jvm/java-25-openjdk"
 
 
 # And a few aliases
-__jvm_openjdk="$__jvm_openjdk20 $__jvm_openjdk19 $__jvm_openjdk18 $__jvm_openjdk17 $__jvm_openjdk11 $__jvm_openjdk10 $__jvm_openjdk9 $__jvm_openjdk8 $__jvm_openjdk7 $__jvm_openjdk6"
+__jvm_openjdk="$__jvm_openjdk25 $__jvm_openjdk24 $__jvm_openjdk23 $__jvm_openjdk22 $__jvm_openjdk21 $__jvm_openjdk17 $__jvm_openjdk11 $__jvm_openjdk8"
 
 # The java* runtimes:
-__jvm_java20="$__jvm_openjdk20 $__jvm_oracle20"
-__jvm_java19="$__jvm_java20 $__jvm_openjdk19 $__jvm_oracle19"
-__jvm_java18="$__jvm_java19 $__jvm_openjdk18 $__jvm_oracle18"
-__jvm_java17="$__jvm_java18 $__jvm_openjdk17 $__jvm_oracle17"
+__jvm_java25="$__jvm_openjdk25 $__jvm_oracle25"
+__jvm_java24="$__jvm_java25 $__jvm_openjdk24 $__jvm_oracle24"
+__jvm_java23="$__jvm_java24 $__jvm_openjdk23 $__jvm_oracle23"
+__jvm_java22="$__jvm_java23 $__jvm_openjdk22 $__jvm_oracle22"
+__jvm_java21="$__jvm_java22 $__jvm_openjdk21 $__jvm_oracle21"
+__jvm_java17="$__jvm_java21 $__jvm_openjdk17 $__jvm_oracle17"
 __jvm_java11="$__jvm_java17 $__jvm_openjdk11 $__jvm_oracle11"
-__jvm_java10="$__jvm_java11 $__jvm_openjdk10 $__jvm_oracle10"
-__jvm_java9="$__jvm_java10 $__jvm_openjdk9 $__jvm_oracle9"
-__jvm_java8="$__jvm_java9 $__jvm_openjdk8 $__jvm_oracle8"
-__jvm_java7="$__jvm_java8 $__jvm_openjdk7 $__jvm_oracle7"
+__jvm_java8="$__jvm_java11 $__jvm_openjdk8 $__jvm_oracle8"
+__jvm_java7="$__jvm_java8"
 # -> corresponds to Provides: java6-runtime
-__jvm_java6="$__jvm_java7 $__jvm_openjdk6"
+__jvm_java6="$__jvm_java7"
 # -> corresponds to Provides: java5-runtime
 __jvm_java5="$__jvm_java6"
 # -> corresponds to Provides: java2-runtime
